pub struct CreateUserSecurityKeyOptions {
pub user_uuid: Uuid,
pub name: CompactString,
pub registration: PasskeyRegistration,
}Fields
user_uuid: Uuidname: CompactStringregistration: PasskeyRegistrationTrait Implementations
Sourceimpl ComposeSchema for CreateUserSecurityKeyOptions
impl ComposeSchema for CreateUserSecurityKeyOptions
Sourceimpl<'de> Deserialize<'de> for CreateUserSecurityKeyOptions
impl<'de> Deserialize<'de> for CreateUserSecurityKeyOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateUserSecurityKeyOptions
impl ToSchema for CreateUserSecurityKeyOptions
Sourceimpl Validate for CreateUserSecurityKeyOptions
impl Validate for CreateUserSecurityKeyOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateUserSecurityKeyOptions
impl RefUnwindSafe for CreateUserSecurityKeyOptions
impl Send for CreateUserSecurityKeyOptions
impl Sync for CreateUserSecurityKeyOptions
impl Unpin for CreateUserSecurityKeyOptions
impl UnwindSafe for CreateUserSecurityKeyOptions