pub struct UpdateUserSecurityKeyOptions {
pub name: Option<CompactString>,
}Fields
name: Option<CompactString>Trait Implementations
Sourceimpl ComposeSchema for UpdateUserSecurityKeyOptions
impl ComposeSchema for UpdateUserSecurityKeyOptions
Sourceimpl Default for UpdateUserSecurityKeyOptions
impl Default for UpdateUserSecurityKeyOptions
Sourcefn default() -> UpdateUserSecurityKeyOptions
fn default() -> UpdateUserSecurityKeyOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateUserSecurityKeyOptions
impl<'de> Deserialize<'de> for UpdateUserSecurityKeyOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for UpdateUserSecurityKeyOptions
impl ToSchema for UpdateUserSecurityKeyOptions
Sourceimpl Validate for UpdateUserSecurityKeyOptions
impl Validate for UpdateUserSecurityKeyOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateUserSecurityKeyOptions
impl RefUnwindSafe for UpdateUserSecurityKeyOptions
impl Send for UpdateUserSecurityKeyOptions
impl Sync for UpdateUserSecurityKeyOptions
impl Unpin for UpdateUserSecurityKeyOptions
impl UnsafeUnpin for UpdateUserSecurityKeyOptions
impl UnwindSafe for UpdateUserSecurityKeyOptions